@@ -3,13 +3,15 @@ Main interface for iot-data service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.iot_data import IoTDataPlaneClient
+    from mypy_boto3_iot_data import IoTDataPlaneClient
 
     session = boto3.Session()
 
     client: IoTDataPlaneClient = boto3.client("iot-data")
     session_client: IoTDataPlaneClient = session.client("iot-data")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Any, Dict, TYPE_CHECKING, Type
