@@ -3,9 +3,11 @@ Main interface for iot-data service type definitions.
 
 Usage::
 
-    from mypy_boto3.iot_data.type_defs import DeleteThingShadowResponseTypeDef
+    ```python
+    from mypy_boto3_iot_data.type_defs import DeleteThingShadowResponseTypeDef
 
     data: DeleteThingShadowResponseTypeDef = {...}
+    ```
 """
 import sys
 
